summaryrefslogtreecommitdiff
path: root/sot/inc/sot/agg.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sot/inc/sot/agg.hxx')
-rw-r--r--sot/inc/sot/agg.hxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/sot/inc/sot/agg.hxx b/sot/inc/sot/agg.hxx
index 2f8cc7587458..cf07f6a8faff 100644
--- a/sot/inc/sot/agg.hxx
+++ b/sot/inc/sot/agg.hxx
@@ -41,21 +41,21 @@ struct SvAggregate
SotFactory * pFact;
SotObject * pObj;
};
- BOOL bFactory;
- BOOL bMainObj; // TRUE, das Objekt, welches das casting steuert
+ sal_Bool bFactory;
+ sal_Bool bMainObj; // sal_True, das Objekt, welches das casting steuert
SvAggregate()
: pFact( NULL )
- , bFactory( FALSE )
- , bMainObj( FALSE ) {}
- SvAggregate( SotObject * pObjP, BOOL bMainP )
+ , bFactory( sal_False )
+ , bMainObj( sal_False ) {}
+ SvAggregate( SotObject * pObjP, sal_Bool bMainP )
: pObj( pObjP )
- , bFactory( FALSE )
+ , bFactory( sal_False )
, bMainObj( bMainP ) {}
SvAggregate( SotFactory * pFactP )
: pFact( pFactP )
- , bFactory( TRUE )
- , bMainObj( FALSE ) {}
+ , bFactory( sal_True )
+ , bMainObj( sal_False ) {}
};
/************** class SvAggregateMemberList *****************************/